@@ -1,9 +1,9 @@
 import troposphere.cloudfront as clf
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj,
-                     change_obj_data, clf_compute_order)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj, change_obj_data,
+                     clf_compute_order)
 
 
 class CFOriginAccessIdentity(clf.CloudFrontOriginAccessIdentity):
