@@ -1,11 +1,12 @@
 import os
-import importlib
+import sys
 import random
 import string
 import copy
 import json
 import logging
 from pprint import pprint, pformat
+from troposphere.autoscaling import Tags as asgTags
 import troposphere.ssm as ssm
 
 from troposphere import (
