@@ -1,9 +1,8 @@
 import troposphere.iam as iam
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj,
-                     SSMParameter)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj, SSMParameter)
 
 
 class IAMUser(iam.User):
@@ -412,7 +411,7 @@ def IAM_Policies(key):
         add_obj(r_Policy)
 
         # outputs
-        if 'Export' in v:
+        if v.get('Export'):
             o_Policy = Output(resname)
             o_Policy.Value = Ref(resname)
             o_Policy.Export = Export(resname)
@@ -436,7 +435,7 @@ def IAM_Roles(key):
         add_obj(r_Role)
 
         # outputs
-        if 'Export' in v:
+        if v.get('Export'):
             o_Role = Output(resname)
             o_Role.Value = GetAtt(resname, 'Arn')
             o_Role.Export = Export(resname)
