@@ -1,9 +1,8 @@
 import troposphere.awslambda as lbd
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj,
-                     import_lambda)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj, import_lambda)
 from .iam import IAMRoleLambdaBase
 
 
@@ -74,7 +73,10 @@ class LambdaFunction(lbd.Function):
         self.FunctionName = Sub('${AWS::StackName}-${EnvRole}-%s' % name)
         if 'Handler' not in key:
             self.Handler = 'index.lambda_handler'
-        self.Role = GetAtt(f'RoleLambda{name}', 'Arn')
+        try:
+            getattr(self, 'Role')
+        except Exception:
+            self.Role = GetAtt(f'RoleLambda{name}', 'Arn')
 
         if all(k in key for k in ['SecurityGroupIds', 'SubnetIds']):
             self.VpcConfig = lbd.VPCConfig('')
@@ -228,17 +230,16 @@ def LBD_Lambdas(key):
                 r_VersionB,
                 o_Version])
 
-        # Automatically setup a lambda Role with base permissions.
-        r_Role = IAMRoleLambdaBase(f'Role{resname}', key=v)
-        if hasattr(r_Lambda, 'Condition'):
-            r_Role.Condition = r_Lambda.Condition
+        if not v.get('SkipRole'):
+            # Automatically setup a lambda Role with base permissions.
+            r_Role = IAMRoleLambdaBase(f'Role{resname}', key=v)
+            if hasattr(r_Lambda, 'Condition'):
+                r_Role.Condition = r_Lambda.Condition
+            add_obj(r_Role)
 
-        add_obj([
-            r_Lambda,
-            r_Role,
-        ])
+        add_obj(r_Lambda)
 
-        if 'Export' in v and v['Export']:
+        if v.get('Export'):
             O_Lambda = Output(resname)
             O_Lambda.Value = GetAtt(resname, 'Arn')
             O_Lambda.Export = Export(resname)
@@ -293,7 +294,6 @@ def LBD_Permissions(key):
 
         # resources
         r_Permission = LambdaPermission(resname)
-        r_Permission.setup()
         auto_get_props(r_Permission)
 
         add_obj([
