@@ -1,8 +1,8 @@
 import troposphere.route53 as r53
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj)
 
 
 class R53RecordSetEFS(r53.RecordSetType):
